use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;

set_spell_cmd('aspell list');
add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Aas
Adam
Alders
Alex
Alexey
Andreas
Bill
Bron
Burke
Chrysostomos
DAVIDRW
Daniel
David
Denaxas
Etheridge
FWILES
Father
Finch
Froehlich
Gavin
Gisle
Gondwana
Graeme
Grossmann
Hanak
Hans
Hay
Hedlund
Hukins
Ian
Jacob
Kapranoff
Karaban
Karen
Kennedy
Kilgore
Koenig
LWP
Lipcon
MARKSTOS
Mann
Mark
MediaTypes
Mike
Olaf
Ondrej
Peter
Peters
Rabbitson
Rezic
Robert
Rolf
Schilli
Schwengle
Sean
Sjogren
Skytta
Slaven
Spiros
Steve
SteveHay
Stone
Stosberg
Thompson
Todd
Tom
Tony
Toru
Tourbin
Ville
Wesley
Wheeler
Yamaguchi
Yuri
Zefram
aas
adamk
amir
amire80
andreas
asjo
at
brong
david
davidrw
denaxas
dot
eg
ether
gisle
github
gpeters
hfroehlich
iank
jefflee
john9art
ka
lib
mark
mschilli
murphy
olaf
ondrej
phrstbrn
rg
ribasushi
ruff
sasao
sburke
shaohua
slaven
sprout
srezic
talby
tech
todd
tom
uid39246
ville
waif
wesley
wfmann
zefram
zigorou
